@@ -14,6 +14,14 @@ from .abstract import AbmServiceAuthedConnector
 
 
 class AbmServicePayloadAuthConnector(AbmServiceAuthedConnector):
+    async def get(self,
+                  path: str,
+                  url_query: Optional[Mapping[str, Any]] = None,
+                  headers: Optional[Mapping[str, str]] = None,
+                  token: str = None,
+                  timeout_sec: Optional[float] = None) -> Any:
+        raise RuntimeError("Attempt to make http GET request by payload auth connector, but GET request has no payload")
+
     async def post(self,
                    path: str,
                    payload: bytes | Jsonable,
